"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.asyncLoadConfig = exports.buildRegexpIfValid = exports.upperCaseFirst = exports.lowerCaseFirst = exports.Omit = exports.attachOrReplaceEntitySubscriber = exports.repositoryMixin = void 0;
const typeorm_1 = require("typeorm");
const medusa_core_utils_1 = require("medusa-core-utils");
/**
 * @deprecated The definition files merging the entities types allow us to get rid of this util. It will be removed in the future
 * For repository context, you should extends repository and the medusa target repository.
 * Since it is not possible to use multiple extend, you can use that utilities to apply multiple extends.
 * @param source
 */
function repositoryMixin(source) {
    const klass = class Base extends typeorm_1.Repository {
    };
    Object.getOwnPropertyNames(source.prototype).forEach((name) => {
        if (name !== 'constructor' && !klass.hasOwnProperty(name)) {
            Object.defineProperty(klass.prototype, name, Object.getOwnPropertyDescriptor(source.prototype, name));
        }
    });
    return klass;
}
exports.repositoryMixin = repositoryMixin;
/**
 * Attach a new subscriber to a specific entities.
 * @param connection The database connection
 * @param Subscriber The subscriber to attach
 * @param transactionalEntityManager The transactional entity manager to pass the transaction through
 */
function attachOrReplaceEntitySubscriber(connection, Subscriber, transactionalEntityManager) {
    const subscriberIndex = connection.subscribers.findIndex((subscriber) => {
        return subscriber.constructor.name === Subscriber.name;
    });
    const subscriberReplacement = new Subscriber(transactionalEntityManager);
    if (subscriberIndex < 0) {
        connection.subscribers.push(subscriberReplacement);
    }
    else {
        connection.subscribers.splice(subscriberIndex, 1, subscriberReplacement);
    }
}
exports.attachOrReplaceEntitySubscriber = attachOrReplaceEntitySubscriber;
/**
 * @deprecated Since this util only acts on the type and not the prototype itself, it adds more confusion for the user. It will be removed in the future
 * Allow to omit some property from a class.
 * @param Class
 * @param keys
 * @constructor
 */
const Omit = (Class, keys) => Class;
exports.Omit = Omit;
/**
 * Lower case the first character of the input string.
 * @param str
 */
function lowerCaseFirst(str) {
    return str.charAt(0).toLowerCase() + str.slice(1);
}
exports.lowerCaseFirst = lowerCaseFirst;
/**
 * Upper case the first character of the input string.
 * @param str
 */
function upperCaseFirst(str) {
    return str.charAt(0).toUpperCase() + str.slice(1);
}
exports.upperCaseFirst = upperCaseFirst;
function buildRegexpIfValid(str) {
    try {
        const m = str.match(/^([/~@;%#'])(.*?)\1([gimsuy]*)$/);
        if (m) {
            const regexp = new RegExp(m[2], m[3]);
            return regexp;
        }
    }
    catch (e) { }
    return;
}
exports.buildRegexpIfValid = buildRegexpIfValid;
async function asyncLoadConfig(rootDir, filename) {
    const configuration = (0, medusa_core_utils_1.getConfigFile)(rootDir !== null && rootDir !== void 0 ? rootDir : process.cwd(), filename !== null && filename !== void 0 ? filename : `medusa-config`);
    const resolveConfigProperties = async (obj) => {
        for (const key of Object.keys(obj)) {
            if (typeof obj[key] === 'object' && obj[key] !== null) {
                await resolveConfigProperties(obj[key]);
            }
            if (typeof obj[key] === 'function') {
                obj[key] = await obj[key]();
            }
        }
        return obj;
    };
    const configModule = await resolveConfigProperties(configuration.configModule);
    return configModule;
}
exports.asyncLoadConfig = asyncLoadConfig;
//# sourceMappingURL=utils.js.map