"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.adminApiLoader = void 0;
const apply_middlewares_1 = require("./helpers/apply-middlewares");
const apply_routers_1 = require("./helpers/apply-routers");
/**
 * @internal
 * Apply middlewares and routes on the underlying @medusajs admin API.
 * @param app
 * @param middlewares
 * @param routers
 */
async function adminApiLoader(app, middlewares, routers) {
    const adminMiddlewares = middlewares
        .map((middleware) => (Object.assign(Object.assign({}, middleware), { routes: middleware.routes
            .filter((route) => route.path.startsWith('/admin'))
            .map((route) => (Object.assign(Object.assign({}, route), { path: route.path.replace('/admin', '') }))) })))
        .filter((middleware) => middleware.routes.length);
    const adminRouters = routers
        .map((router) => (Object.assign(Object.assign({}, router), { routes: router.routes
            .filter((route) => route.path.startsWith('/admin'))
            .map((route) => (Object.assign(Object.assign({}, route), { path: route.path.replace('/admin', '') }))) })))
        .filter((route) => route.routes.length);
    // We are registering the routes and middleware just before medusa created the auth route
    // in order to be placed after the admin initialisation but before any admin routes
    const adminAuthRouteLoader = await Promise.resolve().then(() => require('@medusajs/medusa/dist/api/routes/admin/auth'));
    const originalAdminAuthRouteLoader = adminAuthRouteLoader.default;
    adminAuthRouteLoader.default = (app) => {
        originalAdminAuthRouteLoader(app);
        (0, apply_middlewares_1.applyMiddlewares)('admin', app, adminMiddlewares);
        (0, apply_routers_1.applyRouters)('admin', app, adminRouters);
    };
}
exports.adminApiLoader = adminApiLoader;
//# sourceMappingURL=admin-api.loader.js.map