"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.customApiLoader = void 0;
const apply_middlewares_1 = require("./helpers/apply-middlewares");
const apply_routers_1 = require("./helpers/apply-routers");
/**
 * @internal
 * Apply middlewares and routes on the underlying @medusajs customApi API.
 * @param app
 * @param middlewares
 * @param routers
 */
async function customApiLoader(app, middlewares, routers) {
    const customApiMiddlewares = middlewares
        .map((middleware) => (Object.assign(Object.assign({}, middleware), { routes: middleware.routes.filter((route) => {
            return !route.path.startsWith('/admin') && !route.path.startsWith('/store');
        }) })))
        .filter((middleware) => middleware.routes.length);
    const customApiRouters = routers
        .map((router) => (Object.assign(Object.assign({}, router), { routes: router.routes.filter((route) => {
            return !route.path.startsWith('/admin') && !route.path.startsWith('/store');
        }) })))
        .filter((route) => route.routes.length);
    // We are registering the routes and middleware just before medusa created the auth route
    // in order to be placed after the admin initialisation but before any admin or store routes
    const adminRouteLoader = await Promise.resolve().then(() => require('@medusajs/medusa/dist/api/routes/admin/index'));
    const originalAdminRouteLoader = adminRouteLoader.default;
    adminRouteLoader.default = (app, container, config) => {
        (0, apply_middlewares_1.applyMiddlewares)('custom', app, customApiMiddlewares);
        (0, apply_routers_1.applyRouters)('custom', app, customApiRouters);
        originalAdminRouteLoader(app, container, config);
    };
}
exports.customApiLoader = customApiLoader;
//# sourceMappingURL=custom-api.loader.js.map