"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyMiddlewares = void 0;
const authenticate_1 = require("@medusajs/medusa/dist/api/middlewares/authenticate");
const require_customer_authentication_1 = require("@medusajs/medusa/dist/api/middlewares/require-customer-authentication");
const core_1 = require("../../core");
const logger = core_1.Logger.contextualize('MiddlewaresLoader');
/**
 * @internal
 * Apply middlewares according to their configuration
 * @param domain
 * @param app
 * @param middlewares
 */
function applyMiddlewares(domain, app, middlewares) {
    logger.log('Loading custom middlewares');
    for (const middlewareOptions of middlewares) {
        const { requireAuth, requiredAuth, routes, metatype } = middlewareOptions;
        const handlers = requireAuth || requiredAuth
            ? ((domain === 'admin' || domain === 'custom') && [(0, authenticate_1.default)()]) || [
                (0, require_customer_authentication_1.default)(),
            ]
            : [];
        handlers.push(new metatype().consume);
        routes.some((route) => {
            const { method, path } = route;
            app[method.toLowerCase()](path, ...handlers);
        });
        logger.log(`Middleware loaded - ${middlewareOptions.metatype.name}`);
    }
}
exports.applyMiddlewares = applyMiddlewares;
//# sourceMappingURL=apply-middlewares.js.map