"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyRouters = void 0;
const authenticate_1 = require("@medusajs/medusa/dist/api/middlewares/authenticate");
const require_customer_authentication_1 = require("@medusajs/medusa/dist/api/middlewares/require-customer-authentication");
const core_1 = require("../../core");
const logger = core_1.Logger.contextualize('MiddlewaresLoader');
/**
 * @internal
 * Apply routers according to their configuration
 * @param domain
 * @param app
 * @param routers
 */
function applyRouters(domain, app, routers) {
    logger.log('Loading custom routers');
    for (const routerOptions of routers) {
        routerOptions.routes.forEach((route) => {
            const { method, path, handlers, requiredAuth } = route;
            const handlers_ = requiredAuth
                ? ((domain === 'admin' || domain === 'custom') && [(0, authenticate_1.default)()]) || [
                    (0, require_customer_authentication_1.default)(),
                ]
                : [];
            handlers_.push(...handlers);
            app[method.toLowerCase()](path, ...handlers_);
        });
        logger.log(`Router loaded - ${routerOptions.metatype.name}`);
    }
}
exports.applyRouters = applyRouters;
//# sourceMappingURL=apply-routers.js.map